(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common/http'), require('angular-i18next'), require('rxjs/operators')) :
    typeof define === 'function' && define.amd ? define('angular-i18next-error-interceptor', ['exports', '@angular/core', '@angular/common/http', 'angular-i18next', 'rxjs/operators'], factory) :
    (global = global || self, factory(global['angular-i18next-error-interceptor'] = {}, global.ng.core, global.ng.common.http, global.angularI18next, global.rxjs.operators));
}(this, function (exports, core, http, angularI18next, operators) { 'use strict';

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation. All rights reserved.
    Licensed under the Apache License, Version 2.0 (the "License"); you may not use
    this file except in compliance with the License. You may obtain a copy of the
    License at http://www.apache.org/licenses/LICENSE-2.0

    THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
    WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
    MERCHANTABLITY OR NON-INFRINGEMENT.

    See the Apache Version 2.0 License for specific language governing permissions
    and limitations under the License.
    ***************************************************************************** */

    function __decorate(decorators, target, key, desc) {
        var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
        if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
        else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
        return c > 3 && r && Object.defineProperty(target, key, r), r;
    }

    function __metadata(metadataKey, metadataValue) {
        if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(metadataKey, metadataValue);
    }

    var HTTP_STATUS_DICTIONARY = new core.InjectionToken('HTTP_STATUS_LOCALE_KEYS');

    var I18NextErrorInterceptor = /** @class */ (function () {
        function I18NextErrorInterceptor(injector // https://github.com/angular/angular/issues/18224
        ) {
            this.injector = injector;
            this.statusKeys = this.injector.get(HTTP_STATUS_DICTIONARY);
        }
        I18NextErrorInterceptor.prototype.intercept = function (req, next) {
            var _this = this;
            return next.handle(req).pipe(operators.tap(function (event) { }, function (err) {
                if (err instanceof http.HttpErrorResponse) {
                    _this.HandleErrorMessage(err);
                }
            }));
        };
        I18NextErrorInterceptor.prototype.HandleErrorMessage = function (errorResponse) {
            if (!errorResponse) {
                return errorResponse;
            }
            var errorEntity;
            // if error is object or json string that can be parsed
            try {
                if (errorResponse.error instanceof Object) {
                    errorEntity = errorResponse.error;
                }
                else {
                    errorEntity = JSON.parse(errorResponse.error);
                }
            }
            catch (ex) { }
            // if object got message: server localized message by himself (no need to translate)
            if (!(errorEntity && errorEntity.message)) {
                errorEntity = { message: this.GetLocalizedStatusMessage(errorResponse.status) };
            }
            // modify error response with client localized message
            return new http.HttpErrorResponse(Object.assign(errorResponse, { error: errorEntity }));
        };
        I18NextErrorInterceptor.prototype.GetLocalizedStatusMessage = function (status) {
            if (status === void 0) { status = undefined; }
            var i18nextService = this.injector.get(angularI18next.I18NEXT_SERVICE);
            var errorKey = this.statusKeys[status] || this.statusKeys.default;
            return i18nextService.t(errorKey);
        };
        I18NextErrorInterceptor = __decorate([
            core.Injectable(),
            __metadata("design:paramtypes", [core.Injector // https://github.com/angular/angular/issues/18224
            ])
        ], I18NextErrorInterceptor);
        return I18NextErrorInterceptor;
    }());

    var HttpErrorResponseMessage = /** @class */ (function () {
        function HttpErrorResponseMessage() {
        }
        HttpErrorResponseMessage.prototype.transform = function (httpErrorResp) {
            if (!httpErrorResp || !httpErrorResp.error) {
                return null;
            }
            return httpErrorResp.error.message;
        };
        HttpErrorResponseMessage = __decorate([
            core.Injectable(),
            core.Pipe({
                name: 'httpErrorResponseMessage',
            })
        ], HttpErrorResponseMessage);
        return HttpErrorResponseMessage;
    }());

    var DEFAULT_STATUS_KEYS = {
        400: 'http_error:validation_error',
        401: 'http_error:not_authorized',
        403: 'http_error:access_denied',
        500: 'http_error:internal_server_error',
        'default': 'http_error:unknown_server_error'
    };
    var declarations = [
        HttpErrorResponseMessage
    ];
    var I18NextErrorInterceptorModule = /** @class */ (function () {
        function I18NextErrorInterceptorModule() {
        }
        I18NextErrorInterceptorModule_1 = I18NextErrorInterceptorModule;
        I18NextErrorInterceptorModule.forRoot = function (httpStatusDictionary) {
            if (httpStatusDictionary === void 0) { httpStatusDictionary = null; }
            return {
                ngModule: I18NextErrorInterceptorModule_1,
                providers: [
                    {
                        provide: HTTP_STATUS_DICTIONARY,
                        useValue: httpStatusDictionary || DEFAULT_STATUS_KEYS
                    },
                    {
                        provide: http.HTTP_INTERCEPTORS,
                        useClass: I18NextErrorInterceptor,
                        multi: true
                    }
                ]
            };
        };
        var I18NextErrorInterceptorModule_1;
        I18NextErrorInterceptorModule = I18NextErrorInterceptorModule_1 = __decorate([
            core.NgModule({
                imports: [
                    http.HttpClientModule
                ],
                declarations: declarations,
                exports: declarations,
                providers: [
                    HttpErrorResponseMessage
                ]
            })
        ], I18NextErrorInterceptorModule);
        return I18NextErrorInterceptorModule;
    }());

    exports.DEFAULT_STATUS_KEYS = DEFAULT_STATUS_KEYS;
    exports.HTTP_STATUS_DICTIONARY = HTTP_STATUS_DICTIONARY;
    exports.HttpErrorResponseMessage = HttpErrorResponseMessage;
    exports.I18NextErrorInterceptorModule = I18NextErrorInterceptorModule;
    exports.ɵa = I18NextErrorInterceptor;

    Object.defineProperty(exports, '__esModule', { value: true });

}));
//# sourceMappingURL=angular-i18next-error-interceptor.umd.js.map
