import { InjectionToken, Injectable, Injector, Pipe, NgModule } from '@angular/core';
import { __decorate, __metadata } from 'tslib';
import { HttpErrorResponse, HTTP_INTERCEPTORS, HttpClientModule } from '@angular/common/http';
import { I18NEXT_SERVICE } from 'angular-i18next';
import { tap } from 'rxjs/operators';

var HTTP_STATUS_DICTIONARY = new InjectionToken('HTTP_STATUS_LOCALE_KEYS');

var I18NextErrorInterceptor = /** @class */ (function () {
    function I18NextErrorInterceptor(injector // https://github.com/angular/angular/issues/18224
    ) {
        this.injector = injector;
        this.statusKeys = this.injector.get(HTTP_STATUS_DICTIONARY);
    }
    I18NextErrorInterceptor.prototype.intercept = function (req, next) {
        var _this = this;
        return next.handle(req).pipe(tap(function (event) { }, function (err) {
            if (err instanceof HttpErrorResponse) {
                _this.HandleErrorMessage(err);
            }
        }));
    };
    I18NextErrorInterceptor.prototype.HandleErrorMessage = function (errorResponse) {
        if (!errorResponse) {
            return errorResponse;
        }
        var errorEntity;
        // if error is object or json string that can be parsed
        try {
            if (errorResponse.error instanceof Object) {
                errorEntity = errorResponse.error;
            }
            else {
                errorEntity = JSON.parse(errorResponse.error);
            }
        }
        catch (ex) { }
        // if object got message: server localized message by himself (no need to translate)
        if (!(errorEntity && errorEntity.message)) {
            errorEntity = { message: this.GetLocalizedStatusMessage(errorResponse.status) };
        }
        // modify error response with client localized message
        return new HttpErrorResponse(Object.assign(errorResponse, { error: errorEntity }));
    };
    I18NextErrorInterceptor.prototype.GetLocalizedStatusMessage = function (status) {
        if (status === void 0) { status = undefined; }
        var i18nextService = this.injector.get(I18NEXT_SERVICE);
        var errorKey = this.statusKeys[status] || this.statusKeys.default;
        return i18nextService.t(errorKey);
    };
    I18NextErrorInterceptor = __decorate([
        Injectable(),
        __metadata("design:paramtypes", [Injector // https://github.com/angular/angular/issues/18224
        ])
    ], I18NextErrorInterceptor);
    return I18NextErrorInterceptor;
}());

var HttpErrorResponseMessage = /** @class */ (function () {
    function HttpErrorResponseMessage() {
    }
    HttpErrorResponseMessage.prototype.transform = function (httpErrorResp) {
        if (!httpErrorResp || !httpErrorResp.error) {
            return null;
        }
        return httpErrorResp.error.message;
    };
    HttpErrorResponseMessage = __decorate([
        Injectable(),
        Pipe({
            name: 'httpErrorResponseMessage',
        })
    ], HttpErrorResponseMessage);
    return HttpErrorResponseMessage;
}());

var DEFAULT_STATUS_KEYS = {
    400: 'http_error:validation_error',
    401: 'http_error:not_authorized',
    403: 'http_error:access_denied',
    500: 'http_error:internal_server_error',
    'default': 'http_error:unknown_server_error'
};
var declarations = [
    HttpErrorResponseMessage
];
var I18NextErrorInterceptorModule = /** @class */ (function () {
    function I18NextErrorInterceptorModule() {
    }
    I18NextErrorInterceptorModule_1 = I18NextErrorInterceptorModule;
    I18NextErrorInterceptorModule.forRoot = function (httpStatusDictionary) {
        if (httpStatusDictionary === void 0) { httpStatusDictionary = null; }
        return {
            ngModule: I18NextErrorInterceptorModule_1,
            providers: [
                {
                    provide: HTTP_STATUS_DICTIONARY,
                    useValue: httpStatusDictionary || DEFAULT_STATUS_KEYS
                },
                {
                    provide: HTTP_INTERCEPTORS,
                    useClass: I18NextErrorInterceptor,
                    multi: true
                }
            ]
        };
    };
    var I18NextErrorInterceptorModule_1;
    I18NextErrorInterceptorModule = I18NextErrorInterceptorModule_1 = __decorate([
        NgModule({
            imports: [
                HttpClientModule
            ],
            declarations: declarations,
            exports: declarations,
            providers: [
                HttpErrorResponseMessage
            ]
        })
    ], I18NextErrorInterceptorModule);
    return I18NextErrorInterceptorModule;
}());

/**
 * Generated bundle index. Do not edit.
 */

export { DEFAULT_STATUS_KEYS, HTTP_STATUS_DICTIONARY, HttpErrorResponseMessage, I18NextErrorInterceptorModule, I18NextErrorInterceptor as ɵa };
//# sourceMappingURL=angular-i18next-error-interceptor.js.map
